@@ -1,4 +1,5 @@
 import os.path as path
+import sys
 from dataclasses import dataclass
 from pathlib import Path
 
@@ -6,6 +7,11 @@ from pathlib import Path
 @dataclass
 class Config:
     cpp_libs_dir: str | None = None
+    extra_flags: dict[str, list[str]] | None = None
+    color: bool = sys.stdout.isatty()
+    diff: bool = True
+    ignore_debug: bool = True
+    verbose: bool = False
 
 
 def find_config(dir: str) -> str | None:
@@ -20,7 +26,7 @@ def find_config(dir: str) -> str | None:
     return path.join(p, ".nkconfig.py")
 
 
-def load_config(dir: str) -> Config:
+def exec_config(dir: str) -> Config:
     cfg_path = find_config(dir)
 
     cfg = Config()
