@@ -4,21 +4,36 @@ import re
 import shutil
 import tempfile
 import zipfile
+from dataclasses import dataclass
+from typing import Literal
 
 import appdirs
 import natsort
 import requests
 
+from .config import Config
 from .interactive import spinner
 
-ProblemIO = tuple[str, str | None, str]
+
+@dataclass
+class ProblemIO:
+    """
+    Stores the paths to input, output and a source name.
+    """
+
+    i: str
+    o: str | None
+    from_: Literal["sample"] | Literal["local"]
+
+    def input_name(self):
+        return path.basename(self.i)
 
 
 def problem_dir(problem: str) -> str:
     return path.join(appdirs.user_cache_dir("nekontrol"), "problems", problem)
 
 
-def download_tests(problem: str) -> bool:
+def download_tests(problem: str, config: Config) -> bool:
     url = f"https://open.kattis.com/problems/{problem}/file/statement/samples.zip"
 
     problem_cache_dir = problem_dir(problem)
@@ -27,7 +42,9 @@ def download_tests(problem: str) -> bool:
         print(f"Using cached sample data for problem {problem}")
         return True
     else:
-        with spinner.Spinner(f"Downloading sample data for problem {problem} ") as s:
+        with spinner.Spinner(
+            f"Downloading sample data for problem {problem} ", color=config.color
+        ) as s:
             with requests.get(url, stream=True) as response:
                 if not response.ok:
                     s.fail()
@@ -42,10 +59,10 @@ def download_tests(problem: str) -> bool:
 
 
 def problem_sample_inputs_outputs(
-    problem: str,
-) -> list[tuple[str, str | None, str]] | None:
+    problem: str, config: Config
+) -> list[ProblemIO] | None:
     problem_cache_dir = problem_dir(problem)
-    downloaded = download_tests(problem)
+    downloaded = download_tests(problem, config)
 
     if not downloaded:
         return None
@@ -63,7 +80,7 @@ def problem_sample_inputs_outputs(
 
     ins_and_outs = [(in_file, get_out_file(in_file), "sample") for in_file in in_files]
 
-    return sorted_problems(ins_and_outs)
+    return sorted_problems([ProblemIO(*iof) for iof in ins_and_outs])
 
 
 def local_inputs_outputs(dir: str, name: str) -> list[ProblemIO]:
@@ -76,7 +93,7 @@ def local_inputs_outputs(dir: str, name: str) -> list[ProblemIO]:
     ]
 
     ins_and_outs: list[ProblemIO] = [
-        (
+        ProblemIO(
             path.join(dir, in_),
             out
             if path.isfile(out := path.join(dir, name + m.group(1) + ".ans"))
@@ -92,4 +109,4 @@ def local_inputs_outputs(dir: str, name: str) -> list[ProblemIO]:
 def sorted_problems(
     problems: list[ProblemIO],
 ) -> list[ProblemIO]:
-    return natsort.natsorted(problems, key=lambda tup: tup[0])
+    return natsort.natsorted(problems, key=lambda p: p.i)
